@@ -3,7 +3,7 @@
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
  * Copyright (c) 1999-2008 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-31-2008
+ * Last Modified: 06-23-2008
  *
  * License:
  *
@@ -126,7 +126,7 @@ lifo            *lifo_list=NULL;
 char            *my_strtok_buffer=NULL;
 char            *original_my_strtok_buffer=NULL;
 
-char encoded_url_string[MAX_INPUT_BUFFER];
+char encoded_url_string[2][MAX_INPUT_BUFFER]; // 2 to be able use url_encode twice
 char *encoded_html_string=NULL;
 
 #ifdef HAVE_TZNAME
@@ -1333,50 +1333,51 @@ char * url_encode(char *input){
 	int len,output_len;
 	int x,y;
 	char temp_expansion[4];
-	int expansion_len=0;
+	static int i = 0;
+	char* str = encoded_url_string[i];
+
+	if(input==NULL)
+		return '\x0';
 
 	len=(int)strlen(input);
-	output_len=(int)sizeof(encoded_url_string);
+	output_len=(int)sizeof(encoded_url_string[0]);
 
-	encoded_url_string[0]='\x0';
+	str[0]='\x0';
 
 	for(x=0,y=0;x<=len && y<output_len-1;x++){
 
 		/* end of string */
 		if((char)input[x]==(char)'\x0'){
-			encoded_url_string[y]='\x0';
+			str[y]='\x0';
 			break;
 		        }
 
 		/* alpha-numeric characters and a few other characters don't get encoded */
 		else if(((char)input[x]>='0' && (char)input[x]<='9') || ((char)input[x]>='A' && (char)input[x]<='Z') || ((char)input[x]>=(char)'a' && (char)input[x]<=(char)'z') || (char)input[x]==(char)'.' || (char)input[x]==(char)'-' || (char)input[x]==(char)'_'){
-			encoded_url_string[y]=input[x];
+			str[y]=input[x];
 			y++;
 		        }
 
 		/* spaces are pluses */
-		/*
 		else if((char)input[x]<=(char)' '){
-			encoded_url_string[y]='+';
+			str[y]='+';
 			y++;
 		        }
-		*/
 
 		/* anything else gets represented by its hex value */
 		else{
-			encoded_url_string[y]='\x0';
-			sprintf(temp_expansion,"%%%02X",(unsigned int)(input[x] & 0xFF));
-			expansion_len=strlen(temp_expansion);
-			if((int)strlen(encoded_url_string)<(output_len-expansion_len)){
-				strcat(encoded_url_string,temp_expansion);
-				y+=expansion_len;
+			str[y]='\x0';
+			if((int)strlen(str)<(output_len-3)){
+				sprintf(temp_expansion,"%%%02X",(unsigned int)input[x]);
+				strcat(str,temp_expansion);
+				y+=3;
 			        }
 		        }
 	        }
 
-	encoded_url_string[sizeof(encoded_url_string)-1]='\x0';
+	str[sizeof(encoded_url_string[0])-1]='\x0';
 
-	return &encoded_url_string[0];
+	return str;
         }
 
 
@@ -1788,7 +1789,7 @@ void print_extra_hostgroup_url(char *group_name, char *url){
 	        }
 
 	strncpy(input_buffer,url,sizeof(input_buffer)-1);
-	output_buffer[sizeof(input_buffer)-1]='\x0';
+	input_buffer[sizeof(input_buffer)-1]='\x0';
 
 	for(temp_buffer=my_strtok(input_buffer,"$");temp_buffer!=NULL;temp_buffer=my_strtok(NULL,"$")){
 
@@ -1836,7 +1837,7 @@ void print_extra_servicegroup_url(char *group_name, char *url){
 	        }
 
 	strncpy(input_buffer,url,sizeof(input_buffer)-1);
-	output_buffer[sizeof(input_buffer)-1]='\x0';
+	input_buffer[sizeof(input_buffer)-1]='\x0';
 
 	for(temp_buffer=my_strtok(input_buffer,"$");temp_buffer!=NULL;temp_buffer=my_strtok(NULL,"$")){
 
